@@ -3,6 +3,5 @@
 #' Customize 'Bootstrap' and 'Bootswatch' themes, like colors, fonts, grid layout, to use in 'Shiny' applications.
 #'
 #' @name fresh
-#' @docType package
 #' @author Victor Perrier & Fanny Meyer (\href{https://twitter.com/dreamRs_fr}{@@dreamRs_fr})
-NULL
+"_PACKAGE"
